@@ -28,9 +28,16 @@
 #include <gtkpounce.h>
 #include <gtkutils.h>
 #include <plugin.h>
-#include <stock.h>
+#include <version.h>
+
+#if GAIM_VERSION_CHECK(2,0,0)
+# include <gtkstock.h>
+#else
+# include <stock.h>
+#endif
 
 #include "gf_action.h"
+#include "gf_compat.h"
 #include "gf_display.h"
 #include "gf_event.h"
 #include "gf_event_info.h"
@@ -53,7 +60,7 @@ static GList *actions = NULL;
 GfAction *
 gf_action_new() {
 	GfAction *action;
-
+	
 	action = g_new0(GfAction, 1);
 
 	return action;
@@ -284,7 +291,7 @@ gf_action_execute_open_conv(GfDisplay *display, GdkEventButton *gdk_event) {
 	GaimConversation *conv = NULL;
 	GaimConvWindow *win = NULL;
 	const GHashTable *components = NULL;
-	const gchar *n_type;
+	const gchar *n_type, *target;
 
 	g_return_if_fail(display);
 
@@ -296,7 +303,8 @@ gf_action_execute_open_conv(GfDisplay *display, GdkEventButton *gdk_event) {
 	buddy = gf_event_info_get_buddy(info);
 	conv = gf_event_info_get_conversation(info);
 	components = gf_event_info_get_components(info);
-
+	target = gf_event_info_get_target(info);
+	
 	if(conv) { /* we have a conv */
 		if(conversation_exists(conv)) {
 			win = gaim_conversation_get_window(conv);
@@ -304,36 +312,30 @@ gf_action_execute_open_conv(GfDisplay *display, GdkEventButton *gdk_event) {
 			const gchar *target;
 
 			target = gf_event_info_get_target(info);
-			conv = gaim_find_conversation_with_account(target, account);
-
+			conv = gf_find_conversation(GAIM_CONV_ANY, target, account);
 			if(conv)
 				win = gaim_conversation_get_window(conv);
 		}
 	} else if(components) { /* it's a chat invite */
 		const gchar *extra = gf_event_info_get_extra(info);
 
-		conv = gaim_find_conversation_with_account(extra, account);
+		conv = gf_find_conversation(GAIM_CONV_CHAT, extra, account);
 		if(!conv) {
 			serv_join_chat(account->gc, (GHashTable *)components);
 			gf_display_destroy(display);
 
 			return;
 		}
-	} else if (buddy) { /* we have a buddy */
-		conv = gaim_find_conversation_with_account(buddy->name, account);
-
+	} else if (buddy) { /* we have a buddy or a target */
+		conv = gf_find_conversation(GAIM_CONV_IM, buddy->name, account);
 		if(!conv)
 			conv = gaim_conversation_new(GAIM_CONV_IM, account, buddy->name);
 
 		if(conv)
 			win = gaim_conversation_get_window(conv);
 	} else { /* the only thing that _should_ be left is warnings.. */
-		const gchar *target;
-
-		target = gf_event_info_get_target(info);
-
 		if(target) {
-			conv = gaim_find_conversation_with_account(target, account);
+			conv = gf_find_conversation(GAIM_CONV_IM, target, account);
 
 			if(!conv)
 				conv = gaim_conversation_new(GAIM_CONV_IM, account, target);
@@ -345,7 +347,7 @@ gf_action_execute_open_conv(GfDisplay *display, GdkEventButton *gdk_event) {
 
 	if(win && conv) {
 		gaim_conv_window_raise(win);
-		gaim_conv_window_switch_conversation(win, gaim_conversation_get_index(conv));
+		gf_conv_switch(win, conv);
 
 		if(GAIM_IS_GTK_WINDOW(win))
 			gtk_window_present(GTK_WINDOW(GAIM_GTK_WINDOW(win)->window));
@@ -460,7 +462,36 @@ gf_action_context_info_cb(GtkWidget *menuitem, GfDisplay *display) {
 
 static void
 gf_action_context_im_cb(GtkWidget *menuitem, GfDisplay *display) {
-	gf_action_execute_open_conv(display, NULL);
+	GfEventInfo *info;
+	GaimAccount *account;
+	GaimConversation *conv = NULL;
+	GaimConvWindow *win = NULL;
+	const gchar *target;
+
+	info = gf_display_get_event_info(display);
+
+	account = gf_event_info_get_account(info);
+	target = gf_event_info_get_target(info);
+
+	conv = gf_find_conversation(GAIM_CONV_IM, target, account);
+	if(!conv) {
+		conv = gaim_conversation_new(GAIM_CONV_IM, account, target);
+	}
+
+	if(conv) {
+		win = gaim_conversation_get_window(conv);
+		if(!win) {
+			gf_display_destroy(display);
+			return;
+		}
+		
+		gf_conv_switch(win, conv);
+
+		if(GAIM_IS_GTK_WINDOW(win))
+			gtk_window_present(GTK_WINDOW(GAIM_GTK_WINDOW(win)->window));
+	}
+	
+	gf_display_destroy(display);
 }
 
 static void
@@ -666,8 +697,8 @@ gf_action_context_autojoin_cb(GtkWidget *menuitem, GfDisplay *display) {
 			gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(menuitem)));
 }
 
-/* This function has come from hell.. I summoned it last time I to a wicked
- * to it's external resting place.
+/* This function has come from hell.. I summoned it last time I sent a wicked
+ * soul to it's external resting place.
  */
 void
 gf_action_execute_context(GfDisplay *display, GdkEventButton *gdk_event) {
@@ -743,7 +774,10 @@ gf_action_execute_context(GfDisplay *display, GdkEventButton *gdk_event) {
 								 display, 0, 0, NULL);
 	}
 
-	if(buddy || target) {
+	if(!buddy && target)
+		buddy = gaim_find_buddy(account, target);
+	
+	if(buddy) {
 		gaim_new_item_from_stock(menu, _("View IM log"), NULL,
 								 G_CALLBACK(gf_action_context_log_buddy_cb),
 								 display, 0, 0, NULL);
