@@ -27,9 +27,7 @@ typedef struct _GfAction GfAction;
 
 typedef void (*GfActionFunc)(GfDisplay *display, GdkEventButton *button);
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
+G_BEGIN_DECLS
 
 /* Api */
 GfAction *gf_action_new();
@@ -61,8 +59,6 @@ void gf_action_execute_context(GfDisplay *display, GdkEventButton *gdk_event);
 void gf_action_execute_info(GfDisplay *display, GdkEventButton *gdk_event);
 void gf_action_execute_log(GfDisplay *display, GdkEventButton *gdk_event);
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 #endif /* GF_ACTION_H */
