@@ -25,8 +25,10 @@
 #include <gtkutils.h>
 #include <plugin.h>
 #include <request.h>
+#include <version.h>
 
 #include "gf_blist.h"
+#include "gf_compat.h"
 #include "gf_internal.h"
 #include "gf_notification.h"
 #include "gf_theme.h"
@@ -191,6 +193,7 @@ gf_blist_dialog_new(GaimBlistNode *node) {
 	}
 
 	gaim_request_field_choice_set_default_value(dialog->theme_field, history);
+	gaim_request_field_choice_set_value(dialog->theme_field, history);
 
 	info = g_strdup_printf(_("Select a theme for the %s %s"),
 						   node_type, name);
@@ -231,8 +234,8 @@ gf_blist_drawing_menu_cb(GaimBlistNode *node, GList **menu) {
 	(*menu) = g_list_append(*menu, NULL);
 
 	/* add our menu item */
-	action = gaim_blist_node_action_new(_("Guifications Theme"),
-										gf_blist_menu_cb, NULL);
+	action = gf_blist_node_action_new(_("Guifications Theme"), gf_blist_menu_cb);
+
 	(*menu) = g_list_append(*menu, action);
 }
 
