@@ -26,17 +26,13 @@
 
 #include "gf_notification.h"
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
+G_BEGIN_DECLS
 
 void gf_blist_init(GaimPlugin *plugin);
 void gf_blist_uninit();
 
 GfNotification *gf_blist_get_notification_for_buddy(GaimBuddy *buddy, const gchar *n_type); 
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 #endif /* GF_BLIST_H */
