@@ -38,8 +38,10 @@ typedef BOOL WINAPI GF_GetMonitorInfo(HMONITOR,LPMONITORINFO);
 
 #include <debug.h>
 #include <prefs.h>
+#include <version.h>
 
 #include "gf_action.h"
+#include "gf_compat.h"
 #include "gf_event_info.h"
 #include "gf_notification.h"
 #include "gf_preferences.h"
@@ -1280,7 +1282,7 @@ static guint scr_chg_id = 0, mon_chg_id = 0;
 static guint pos_chg_id = 0, ver_chg_id = 0, ani_chg_id = 0;
 
 void
-gf_display_init() {
+gf_display_init(GaimPlugin *plugin) {
 	/* since we just use the callbacks to get the changes we need to know
 	 * what these are initially at.
 	 */
@@ -1289,27 +1291,32 @@ gf_display_init() {
 	animate = gaim_prefs_get_bool(GF_PREF_APPEARANCE_ANIMATE);
 
 	/* Connect our pref callbacks */
-	pos_chg_id = gaim_prefs_connect_callback(GF_PREF_APPEARANCE_POSITION,
-											 gf_display_position_changed_cb,
-											 NULL);
-	ver_chg_id = gaim_prefs_connect_callback(GF_PREF_APPEARANCE_VERTICAL,
-											 gf_display_position_changed_cb,
-											 NULL);
-	ani_chg_id = gaim_prefs_connect_callback(GF_PREF_APPEARANCE_ANIMATE,
-											 gf_display_animate_changed_cb,
-											 NULL);
+	pos_chg_id = gf_prefs_connect_callback(plugin,
+										   GF_PREF_APPEARANCE_POSITION,
+										   gf_display_position_changed_cb,
+										   NULL);
+	ver_chg_id = gf_prefs_connect_callback(plugin,
+										   GF_PREF_APPEARANCE_VERTICAL,
+										   gf_display_position_changed_cb,
+										   NULL);
+	ani_chg_id = gf_prefs_connect_callback(plugin,
+										   GF_PREF_APPEARANCE_ANIMATE,
+										   gf_display_animate_changed_cb,
+										   NULL);
 
 #if GTK_CHECK_VERSION(2,2,0)
 	/* setup our multi screen prefs */
 	disp_screen = gaim_prefs_get_int(GF_PREF_ADVANCED_SCREEN);
 	disp_monitor = gaim_prefs_get_int(GF_PREF_ADVANCED_MONITOR);
 
-	scr_chg_id = gaim_prefs_connect_callback(GF_PREF_ADVANCED_SCREEN,
-											 gf_display_screen_changed_cb,
-											 NULL);
-	mon_chg_id = gaim_prefs_connect_callback(GF_PREF_ADVANCED_MONITOR,
-											 gf_display_monitor_changed_cb,
-											 NULL);
+	scr_chg_id = gf_prefs_connect_callback(plugin,
+										   GF_PREF_ADVANCED_SCREEN,
+										   gf_display_screen_changed_cb,
+										   NULL);
+	mon_chg_id = gf_prefs_connect_callback(plugin,
+										   GF_PREF_ADVANCED_MONITOR,
+										   gf_display_monitor_changed_cb,
+										   NULL);
 #endif /* GTK_CHECK_VERSION(2,2,0) */
 }
 
