@@ -25,6 +25,8 @@ typedef struct _GfDisplay GfDisplay;
 
 #include <glib.h>
 
+#include <plugin.h>
+
 #include "gf_event_info.h"
 #include "gf_notification.h"
 
@@ -48,10 +50,7 @@ typedef enum _GfDisplayZoom {
 	GF_DISPLAY_ZOOM_UNKNOWN
 } GfDisplayZoom;
 
-
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
+G_BEGIN_DECLS
 
 GfDisplay *gf_display_new();
 void gf_display_destroy(GfDisplay *display);
@@ -60,7 +59,7 @@ GfEventInfo *gf_display_get_event_info(GfDisplay *display);
 
 void gf_display_show_event(GfEventInfo *info, GfNotification *notification);
 
-void gf_display_init();
+void gf_display_init(GaimPlugin *plugin);
 void gf_display_uninit();
 
 #if GTK_CHECK_VERSION(2,2,0)
@@ -72,8 +71,6 @@ gint gf_display_get_monitor_count();
 
 gboolean gf_display_screen_saver_is_running();
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 #endif /* GF_DISPLAY_H */
