@@ -24,11 +24,18 @@
 #include <blist.h>
 #include <connection.h>
 #include <conversation.h>
+#include <notify.h>
 #include <plugin.h>
 #include <prefs.h>
 #include <util.h>
+#include <version.h>
+
+#if GAIM_VERSION_CHECK(2,0,0)
+# include <status.h>
+#endif /* GAIM_VERSION_CHECK(2,0,0) */
 
 #include "gf_blist.h"
+#include "gf_compat.h"
 #include "gf_display.h"
 #include "gf_event.h"
 #include "gf_internal.h"
@@ -298,11 +305,9 @@ gf_event_should_show(const gchar *notification, GaimAccount *account) {
 	if(!gf_event_show_notification(notification))
 		return FALSE;
 
-	if(!gaim_prefs_get_bool(GF_PREF_BEHAVIOR_SHOW_WHILE_AWAY) &&
-	   account->gc->away_state)
-	{
-		return FALSE;
-	}
+	if(!gaim_prefs_get_bool(GF_PREF_BEHAVIOR_SHOW_WHILE_AWAY))
+		if(!gf_presence_is_valid(account))
+			return FALSE;
 
 	return TRUE;
 }
@@ -405,16 +410,27 @@ gf_event_buddy(GaimBuddy *buddy, gpointer data) {
 /*******************************************************************************
  * Conversation callbacks
  ******************************************************************************/
+#if GAIM_VERSION_CHECK(2,0,0)
+static void
+gf_event_im_message(GaimAccount *account, const gchar *sender,
+					const gchar *message, GaimConversation *conv, gint flags,
+					gpointer data)
+{
+#else /* GAIM_VERSION_CHECK(2,0,0) */
 static void
 gf_event_im_message(GaimAccount *account, const gchar *sender,
 					const gchar *message, int flags, gpointer data)
 {
 	GaimConversation *conv = NULL;
+#endif /* GAIM_VERSION_CHECK(2,0,0) */
 	GaimBuddy *buddy = NULL;
 	gchar *notification = (gchar *)data;
 	gchar *plain_message = NULL;
 
+#if !GAIM_VERSION_CHECK(2,0,0)
 	conv = gaim_find_conversation_with_account(sender, account);
+#endif /* !GAIM_VERSION_CHECK(2,0,0) */
+	
 	buddy = gaim_find_buddy(account, sender);
 	plain_message = gaim_markup_strip_html(message);
 
@@ -423,10 +439,17 @@ gf_event_im_message(GaimAccount *account, const gchar *sender,
 	g_free(plain_message);
 }
 
+#if GAIM_VERSION_CHECK(2,0,0)
+static void
+gf_event_chat_message(GaimAccount *account, const gchar *sender,
+					  const gchar *message, GaimConversation *conv, gint flags,
+					  gpointer data)
+#else /* !GAIM_VERSION_CHECK(2,0,0) */
 static void
 gf_event_chat_message(GaimAccount *account, const gchar *sender,
 					  const gchar *message, GaimConversation *conv,
 					  gpointer data)
+#endif /* GAIM_VERSION_CHECK(2,0,0) */
 {
 	GaimBuddy *buddy = NULL;
 	gchar *notification = (gchar *)data;
@@ -565,6 +588,56 @@ gf_event_account(GaimAccount *account, const gchar *warner,
 					GAIM_CBFLAGS_NONE, NULL, NULL);
 }
 
+/*******************************************************************************
+ * Mail Stuff
+ ******************************************************************************/
+#ifdef EMAIL
+static void *
+gf_event_emails(size_t count, gboolean detailed, const gchar **subjects,
+				const gchar **froms, const gchar **tos, const gchar **urls,
+				GCallback cb, gpointer data)
+{
+
+	
+	return NULL;
+}
+	
+static void *
+gf_event_email(const gchar *subject, const gchar *from, const gchar *to,
+			   const gchar *url, GCallback cb, gpointer data)
+{
+	return gf_event_emails(1, TRUE,
+						   subject ? &subject : NULL,
+						   from ? &from : NULL,
+						   to ? &to : NULL,
+						   url ? &url : NULL,
+						   cb, data);
+}
+
+static GaimNotifyUiOps *notify_ops_orig = NULL, *notify_ops_new = NULL;
+
+static void
+gf_event_email_init() {
+	g_return_if_fail(!notify_ops_new);
+	
+	notify_ops_orig = gaim_notify_get_ui_ops();
+
+	notify_ops_new = g_memdup(notify_ops_orig, sizeof(GaimNotifyUiOps));
+	notify_ops_new->notify_email = gf_event_email;
+	notify_ops_new->notify_emails = gf_event_emails;
+
+	gaim_notify_set_ui_ops(notify_ops_new);
+}
+
+static void gf_event_email_uninit() {
+	g_return_if_fail(notify_ops_new);
+
+	gaim_notify_set_ui_ops(notify_ops_orig);
+	g_free(notify_ops_new);
+	notify_ops_new = NULL;
+}
+#endif
+
 /*******************************************************************************
  * Subsystem
  ******************************************************************************/
@@ -633,6 +706,12 @@ gf_events_init(GaimPlugin *plugin) {
 				 _("Displayed when you are warned."),
 				 GF_EVENT_PRIORITY_NORMAL);
 
+#ifdef EMAIL
+	gf_event_new("email", "%DdHhiMmNsTtuYy", _("Email"),
+				 _("Displayed when you receive new email."),
+				 GF_EVENT_PRIORITY_NORMAL);
+#endif
+	
 	gf_event_new(GF_NOTIFICATION_MASTER, TOKENS_DEFAULT "Ccnr",
 				 _("Master"), _("Master notification for the theme editor."),
 				 GF_EVENT_PRIORITY_NORMAL);
@@ -715,12 +794,20 @@ gf_events_init(GaimPlugin *plugin) {
 	gaim_signal_connect(conv_handle, "chat-joined", plugin,
 						GAIM_CALLBACK(gf_event_conversation_throttle), NULL);
 
+#ifdef EMAIL
+	/* mail stuff */
+	gf_event_email_init();
+#endif
 }
 
 void
 gf_events_uninit() {
 	GList *l, *ll;
 
+#ifdef EMAIL
+	gf_event_email_uninit();
+#endif
+	
 	for(l = events; l; l = ll) {
 		ll = l->next;
 		gf_event_destroy(GF_EVENT(l->data));
