@@ -43,6 +43,8 @@ struct _GfEventInfo {
 	gchar *message;
 	gchar *extra;
 	const GHashTable *components;
+
+	GCallback open_action;
 };
 
 /*******************************************************************************
@@ -252,3 +254,17 @@ gf_event_info_get_is_contact(GfEventInfo *info) {
 
 	return info->contact;
 }
+
+void
+gf_event_info_set_open_action(GfEventInfo *info, GCallback open_action) {
+	g_return_if_fail(info);
+
+	info->open_action = open_action;
+}
+
+GCallback
+gf_event_info_get_open_action(const GfEventInfo *info) {
+	g_return_val_if_fail(info, NULL);
+
+	return info->open_action;
+}
