@@ -38,9 +38,7 @@ typedef enum _GfEventType {
 #include "gf_event.h"
 #include "gf_notification.h"
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
+G_BEGIN_DECLS
 
 GfEventInfo *gf_event_info_new(const gchar *notification_type);
 void gf_event_info_destroy(GfEventInfo *info);
@@ -68,9 +66,9 @@ void gf_event_info_set_conv_chat_buddy_flags(GfEventInfo *info, GaimConvChatBudd
 GaimConvChatBuddyFlags gf_event_info_get_chat_buddy_flags(GfEventInfo *info);
 void gf_event_info_set_is_contact(GfEventInfo *info, gboolean value);
 gboolean gf_event_info_get_is_contact(GfEventInfo *info);
+void gf_event_info_set_open_action(GfEventInfo *info, GCallback open_action);
+GCallback gf_event_info_get_open_action(const GfEventInfo *info);
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 #endif /* GF_EVENT_INFO_H */
