@@ -21,17 +21,13 @@
 
 #include <glib.h>
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
+G_BEGIN_DECLS
 
 gboolean gf_file_copy_file(const gchar *source, const gchar *dest);
 gboolean gf_file_copy_directory(const gchar *source, const gchar *destination);
 void gf_file_remove_dir(const gchar *directory);
 gint gf_file_access(const gchar *filename, gint mode);
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 #endif /* GF_FILE_H */
