@@ -54,9 +54,7 @@ typedef enum _GfItemPosition {
 
 #include "xmlnode.h"
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
+G_BEGIN_DECLS
 
 GfItem *gf_item_new(GfNotification *notification);
 GfItem *gf_item_new_from_xmlnode(GfNotification *notification, xmlnode *node);
@@ -93,8 +91,6 @@ void gf_item_render(GfItem *item, GdkPixbuf *pixbuf, GfEventInfo *info);
 
 void gf_items_swap(GfItem *item1, GfItem *item2);
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 #endif /* GF_ITEM_H */
