@@ -26,6 +26,7 @@
 #include <xmlnode.h>
 #include <gtkblist.h>
 
+#include "gf_compat.h"
 #include "gf_gtk_utils.h"
 #include "gf_internal.h"
 #include "gf_item.h"
@@ -281,11 +282,13 @@ gf_item_icon_render(GfItemIcon *item_icon, GdkPixbuf *pixbuf, GfEventInfo *info)
 		if(is_contact) {
 			gchar *filename;
 
-			filename = g_build_filename(DATADIR, "pixmaps", "gaim.png", NULL);
+			filename = g_build_filename(DATADIR, "pixmaps", "gaim.png",
+										NULL);
 			original = gdk_pixbuf_new_from_file(filename, NULL);
 			g_free(filename);
 		} else {
-			original = create_prpl_icon(gf_event_info_get_account(info));
+			GaimAccount *account = gf_event_info_get_account(info);
+			original = gf_create_prpl_icon(account);
 		}
 	} else if(item_icon->type == GF_ITEM_ICON_TYPE_BUDDY) {
 		GaimBuddyIcon *icon = NULL;
@@ -320,7 +323,11 @@ gf_item_icon_render(GfItemIcon *item_icon, GdkPixbuf *pixbuf, GfEventInfo *info)
 	 * "enhance" the theme format.  If it fails we return like we used to.
 	 */
 	if(!original) {
-		if(!(original = create_prpl_icon(gf_event_info_get_account(info))))
+		GaimAccount *account = gf_event_info_get_account(info);
+		
+		original = gf_create_prpl_icon(account);
+		
+		if(!original)
 			return;
 	}
 
