@@ -48,9 +48,7 @@ typedef struct _GfItemIcon GfItemIcon;
 #include "gf_event_info.h"
 #include "gf_item.h"
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
+G_BEGIN_DECLS
 
 GfItemIcon *gf_item_icon_new(GfItem *item);
 GfItemIcon *gf_item_icon_new_from_xmlnode(GfItem *item, xmlnode *node);
@@ -69,8 +67,6 @@ GfItem *gf_item_icon_get_item(GfItemIcon *icon);
 void gf_item_icon_render(GfItemIcon *item_icon, GdkPixbuf *pixbuf,
 						 GfEventInfo *info);
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 #endif /* GF_ITEM_ICON_H */
