@@ -31,9 +31,7 @@
 
 typedef struct _GfItemImage GfItemImage;
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
+G_BEGIN_DECLS
 
 GfItemImage *gf_item_image_new(GfItem *item);
 GfItemImage *gf_item_image_new_from_xmlnode(GfItem *item, xmlnode *node);
@@ -48,8 +46,6 @@ const gchar *gf_item_image_get_image(GfItemImage *item_image);
 
 void gf_item_image_render(GfItemImage *item_image, GdkPixbuf *pixbuf, GfEventInfo *info);
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 #endif /* GF_ITEM_IMAGE_H */
