@@ -25,9 +25,7 @@
 
 typedef struct _GfItemOffset GfItemOffset;
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
+G_BEGIN_DECLS
 
 GfItemOffset *gf_item_offset_new(GfItem *item);
 GfItemOffset *gf_item_offset_new_from_xmlnode(GfItem *item, xmlnode *node);
@@ -42,8 +40,6 @@ gboolean gf_item_offset_get_is_percentage(GfItemOffset *offset);
 
 GfItem *gf_item_offset_get_item(GfItemOffset *offset);
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 #endif /* GF_ITEM_OFFSET_H */
