@@ -45,11 +45,17 @@
 #include <prpl.h>
 #include <util.h>
 #include <xmlnode.h>
+#include <version.h>
+
+#if GAIM_VERSION_CHECK(2,0,0)
+# include <status.h>
+#endif /* GAIM_VERSION_CHECK(2,0,0) */
 
 #ifndef _WIN32
 # include <gdk/gdkx.h>
 #endif
 
+#include "gf_compat.h"
 #include "gf_event.h"
 #include "gf_event_info.h"
 #include "gf_gtk_utils.h"
@@ -490,10 +496,11 @@ gf_item_text_parse_format(GfItemText *item_text, GfEventInfo *info) {
 					GaimChat *chat;
 
 					chat = gaim_blist_find_chat(account, conv->name);
-					if(chat)
-						str = g_string_append(str, gaim_chat_get_display_name(chat));
-					else
+					if(chat) {
+						str = g_string_append(str, gf_chat_get_name(chat));
+					} else {
 						str = g_string_append(str, conv->name);
+					}
 				} else {
 					str = g_string_append(str, conv->name);
 				}
@@ -608,7 +615,8 @@ gf_item_text_parse_format(GfItemText *item_text, GfEventInfo *info) {
 					if(!g_ascii_strcasecmp(prpl_id, "prpl-toc") ||
 					   !g_ascii_strcasecmp(prpl_id, "prpl-oscar"))
 					{
-						g_string_append_printf(str, "%d", buddy->evil);
+						g_string_append_printf(str, "%d",
+							gf_get_warning_level(buddy));
 					} else {
 						str = g_string_append(str, warning);
 					}
@@ -674,7 +682,7 @@ g_utf8_strreverse(const gchar *str, gssize len) {
 
 /* this will probably break.. be sure to test it!!! */
 static gchar *
-gf_utf8_strrncpy(const gchar *text, gint n) {
+gf_utf8_strrndup(const gchar *text, gint n) {
 	gchar *rev = NULL, *tmp = NULL;
 
 	rev = g_utf8_strreverse(text, -1);
@@ -737,8 +745,7 @@ text_ellipsis_start(PangoLayout *layout, gint width, gint offset,
 			break;
 
 		text = pango_layout_get_text(layout);
-		new_text = g_strdup(text);
-		new_text = gf_utf8_strrncpy(text, g_utf8_strlen(text, -1) - 1);
+		new_text = gf_utf8_strrndup(text, g_utf8_strlen(text, -1) - 1);
 		pango_layout_set_text(layout, new_text, -1);
 		g_free(new_text);
 	}
@@ -771,11 +778,10 @@ text_ellipsis_middle(PangoLayout *layout, gint width, gint offset,
 		left_text = g_strdup(text);
 		left_text = g_utf8_strncpy(left_text, text, mid);
 
-		right_text = g_strdup(text);
 		if(IS_EVEN(g_utf8_strlen(text, -1)))
-			right_text = gf_utf8_strrncpy(text, mid - 1);
+			right_text = gf_utf8_strrndup(text, mid - 1);
 		else
-			right_text = gf_utf8_strrncpy(text, mid);
+			right_text = gf_utf8_strrndup(text, mid);
 
 		new_text = g_strdup_printf("%s%s", left_text, right_text);
 		g_free(left_text);
@@ -791,9 +797,9 @@ text_ellipsis_middle(PangoLayout *layout, gint width, gint offset,
 	left_text = g_strdup(text);
 	left_text = g_utf8_strncpy(left_text, text, mid);
 	if(IS_EVEN(g_utf8_strlen(text, -1)))
-		right_text = gf_utf8_strrncpy(text, mid - 1);
+		right_text = gf_utf8_strrndup(text, mid - 1);
 	else
-		right_text = gf_utf8_strrncpy(text, mid);
+		right_text = gf_utf8_strrndup(text, mid);
 
 	new_text = g_strdup_printf("%s%s%s", left_text, ellipsis_text, right_text);
 	g_free(left_text);
