@@ -39,9 +39,7 @@ typedef struct _GfItemText GfItemText;
 #include "gf_item.h"
 #include "gf_event_info.h"
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
+G_BEGIN_DECLS
 
 void gf_item_text_init();
 void gf_item_text_uninit();
@@ -67,8 +65,6 @@ GfItem *gf_item_text_get_item(GfItemText *item_text);
 
 void gf_item_text_render(GfItemText *item_text, GdkPixbuf *pixbuf, GfEventInfo *info);
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 #endif /* GF_ITEM_TEXT_H */
