@@ -48,14 +48,12 @@ gf_menu_make_item(GtkWidget *image, const gchar *text) {
 }
 
 GtkWidget *
-gf_menu_build(GfMenuItemBuilder builder) {
+gf_menu_build(GfMenuItemBuilder builder, void *data) {
 	GtkWidget *menu;
 	gint i, max;
 
 	if(builder == gf_menu_position)
 		max = 4;
-	else if(builder == gf_menu_zoom)
-		max = 8;
 	else if(builder == gf_menu_mouse)
 		max = gf_actions_count();
 	else if(builder == gf_menu_event)
@@ -76,7 +74,7 @@ gf_menu_build(GfMenuItemBuilder builder) {
 	menu = gtk_menu_new();
 
 	for(i = 0; i < max; i++)
-		builder(menu, i);
+		builder(menu, i, data);
 
 	gtk_widget_show_all(menu);
 
@@ -84,7 +82,7 @@ gf_menu_build(GfMenuItemBuilder builder) {
 }
 
 GtkWidget *
-gf_menu_position(GtkWidget *menu, gint item) {
+gf_menu_position(GtkWidget *menu, gint item, void *data) {
 	GtkWidget *menu_item = NULL, *image;
 
 	g_return_val_if_fail(menu, NULL);
@@ -122,65 +120,7 @@ gf_menu_position(GtkWidget *menu, gint item) {
 }
 
 GtkWidget *
-gf_menu_zoom(GtkWidget *menu, gint item) {
-	GtkWidget *menu_item = NULL, *image;
-
-	g_return_val_if_fail(menu, NULL);
-
-	switch(item) {
-		case GF_DISPLAY_ZOOM_200:
-			image = gtk_image_new_from_stock(GF_STOCK_WINDOW_ZOOM_IN,
-											 GTK_ICON_SIZE_MENU);
-			menu_item = gf_menu_make_item(image, _("200%"));
-			break;
-		case GF_DISPLAY_ZOOM_175:
-			image = gtk_image_new_from_stock(GF_STOCK_WINDOW_ZOOM_IN,
-											 GTK_ICON_SIZE_MENU);
-			menu_item = gf_menu_make_item(image, _("175%"));
-			break;
-		case GF_DISPLAY_ZOOM_150:
-			image = gtk_image_new_from_stock(GF_STOCK_WINDOW_ZOOM_IN,
-											 GTK_ICON_SIZE_MENU);
-			menu_item = gf_menu_make_item(image, _("150%"));
-			break;
-		case GF_DISPLAY_ZOOM_125:
-			image = gtk_image_new_from_stock(GF_STOCK_WINDOW_ZOOM_IN,
-											 GTK_ICON_SIZE_MENU);
-			menu_item = gf_menu_make_item(image, _("125%"));
-			break;
-		case GF_DISPLAY_ZOOM_100:
-			image = gtk_image_new_from_stock(GF_STOCK_WINDOW_ZOOM_NORMAL,
-											 GTK_ICON_SIZE_MENU);
-			menu_item = gf_menu_make_item(image, _("100%"));
-			break;
-		case GF_DISPLAY_ZOOM_75:
-			image = gtk_image_new_from_stock(GF_STOCK_WINDOW_ZOOM_OUT,
-											 GTK_ICON_SIZE_MENU);
-			menu_item = gf_menu_make_item(image, _("75%"));
-			break;
-		case GF_DISPLAY_ZOOM_50:
-			image = gtk_image_new_from_stock(GF_STOCK_WINDOW_ZOOM_OUT,
-											 GTK_ICON_SIZE_MENU);
-			menu_item = gf_menu_make_item(image, _("50%"));
-			break;
-		case GF_DISPLAY_ZOOM_25:
-			image = gtk_image_new_from_stock(GF_STOCK_WINDOW_ZOOM_OUT,
-											 GTK_ICON_SIZE_MENU);
-			menu_item = gf_menu_make_item(image, _("25%"));
-			break;
-		case GF_DISPLAY_ZOOM_UNKNOWN:
-		default:
-			break;
-	}
-
-	if(menu_item)
-		gtk_menu_shell_append(GTK_MENU_SHELL(menu), menu_item);
-
-	return menu_item;
-}
-
-GtkWidget *
-gf_menu_mouse(GtkWidget *menu, gint item) {
+gf_menu_mouse(GtkWidget *menu, gint item, void *data) {
 	GtkWidget *menu_item = NULL;
 
 	g_return_val_if_fail(menu, NULL);
@@ -194,12 +134,21 @@ gf_menu_mouse(GtkWidget *menu, gint item) {
 }
 
 GtkWidget *
-gf_menu_event(GtkWidget *menu, gint item) {
+gf_menu_event(GtkWidget *menu, gint item, void *data) {
 	GtkWidget *menu_item = NULL;
+	const gchar *name = NULL;
 
 	g_return_val_if_fail(menu, NULL);
 
-	menu_item = gf_menu_make_item(NULL, gf_events_get_nth_name(item));
+	name = gf_events_get_nth_name(item);
+	menu_item = gf_menu_make_item(NULL, name);
+
+	if(!g_utf8_collate(name, GF_NOTIFICATION_MASTER)) {
+		GfTheme *theme = GF_THEME(data);
+
+		if(theme && gf_theme_get_master(theme))
+			gtk_widget_set_sensitive(menu_item, FALSE);
+	}
 
 	if(menu_item)
 		gtk_menu_shell_append(GTK_MENU_SHELL(menu), menu_item);
@@ -208,7 +157,7 @@ gf_menu_event(GtkWidget *menu, gint item) {
 }
 
 GtkWidget *
-gf_menu_item_position(GtkWidget *menu, gint item) {
+gf_menu_item_position(GtkWidget *menu, gint item, void *data) {
 	GtkWidget *menu_item = NULL, *image = NULL;
 
 	g_return_val_if_fail(menu, NULL);
@@ -266,7 +215,7 @@ gf_menu_item_position(GtkWidget *menu, gint item) {
 }
 
 GtkWidget *
-gf_menu_item_type(GtkWidget *menu, gint item) {
+gf_menu_item_type(GtkWidget *menu, gint item, void *data) {
 	GtkWidget *menu_item = NULL;
 
 	switch(item) {
@@ -294,7 +243,7 @@ gf_menu_item_type(GtkWidget *menu, gint item) {
 }
 
 GtkWidget *
-gf_menu_item_icon_type(GtkWidget *menu, gint item) {
+gf_menu_item_icon_type(GtkWidget *menu, gint item, void *data) {
 	GtkWidget *menu_item = NULL;
 
 	g_return_val_if_fail(menu, NULL);
@@ -321,7 +270,7 @@ gf_menu_item_icon_type(GtkWidget *menu, gint item) {
 }
 
 GtkWidget *
-gf_menu_item_icon_size(GtkWidget *menu, gint item) {
+gf_menu_item_icon_size(GtkWidget *menu, gint item, void *data) {
 	GtkWidget *menu_item = NULL, *image;
 
 	g_return_val_if_fail(menu, NULL);
@@ -374,7 +323,7 @@ gf_menu_item_icon_size(GtkWidget *menu, gint item) {
 }
 
 GtkWidget *
-gf_menu_item_text_clipping(GtkWidget *menu, gint item) {
+gf_menu_item_text_clipping(GtkWidget *menu, gint item, void *data) {
 	GtkWidget *menu_item = NULL, *image;
 
 	g_return_val_if_fail(menu, NULL);
