@@ -21,26 +21,21 @@
 
 #include <gtk/gtk.h>
 
-typedef GtkWidget *(*GfMenuItemBuilder)(GtkWidget *menu, gint num);
+typedef GtkWidget *(*GfMenuItemBuilder)(GtkWidget *menu, gint num, void *data);
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
+G_BEGIN_DECLS
 
-GtkWidget *gf_menu_build(GfMenuItemBuilder builder);
+GtkWidget *gf_menu_build(GfMenuItemBuilder builder, void *data);
 
-GtkWidget *gf_menu_position(GtkWidget *menu, gint item);
-GtkWidget *gf_menu_zoom(GtkWidget *menu, gint item);
-GtkWidget *gf_menu_mouse(GtkWidget *menu, gint item);
-GtkWidget *gf_menu_event(GtkWidget *menu, gint item);
-GtkWidget *gf_menu_item_position(GtkWidget *menu, gint item);
-GtkWidget *gf_menu_item_type(GtkWidget *menu, gint item);
-GtkWidget *gf_menu_item_icon_type(GtkWidget *menu, gint item);
-GtkWidget *gf_menu_item_icon_size(GtkWidget *menu, gint item);
-GtkWidget *gf_menu_item_text_clipping(GtkWidget *menu, gint item);
+GtkWidget *gf_menu_position(GtkWidget *menu, gint item, void *data);
+GtkWidget *gf_menu_mouse(GtkWidget *menu, gint item, void *data);
+GtkWidget *gf_menu_event(GtkWidget *menu, gint item, void *data);
+GtkWidget *gf_menu_item_position(GtkWidget *menu, gint item, void *data);
+GtkWidget *gf_menu_item_type(GtkWidget *menu, gint item, void *data);
+GtkWidget *gf_menu_item_icon_type(GtkWidget *menu, gint item, void *data);
+GtkWidget *gf_menu_item_icon_size(GtkWidget *menu, gint item, void *data);
+GtkWidget *gf_menu_item_text_clipping(GtkWidget *menu, gint item, void *data);
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 #endif
