@@ -36,6 +36,7 @@
 struct _GfNotification {
 	GfTheme *theme;
 	gchar *n_type;
+	gchar *alias;
 
 	gboolean use_gtk;
 	gchar *background;
@@ -56,8 +57,9 @@ gf_notification_new(GfTheme *theme) {
 
 	notification = g_new0(GfNotification, 1);
 	notification->theme = theme;
-	notification->height = 16;
-	notification->width = 16;
+	notification->use_gtk = TRUE;
+	notification->height = 140;
+	notification->width = 120;
 
 	return notification;
 }
@@ -81,6 +83,9 @@ gf_notification_new_from_xmlnode(GfTheme *theme, xmlnode *node) {
 		return NULL;
 	}
 
+	if(!g_utf8_collate(notification->n_type, GF_NOTIFICATION_MASTER))
+		gf_theme_set_master(theme, notification);
+
 	data = xmlnode_get_attrib(node, "use_gtk");
 	if(data)
 		notification->use_gtk = atoi(data);
@@ -97,6 +102,10 @@ gf_notification_new_from_xmlnode(GfTheme *theme, xmlnode *node) {
 	if(data)
 		notification->height = atoi(data);
 
+	data = xmlnode_get_attrib(node, "alias");
+	if(data)
+		notification->alias = g_strdup(data);
+
 	if(notification->use_gtk) {
 		if(notification->width < GF_NOTIFICATION_MIN ||
 		   notification->height < GF_NOTIFICATION_MIN)
@@ -146,6 +155,13 @@ gf_notification_copy(GfNotification *notification) {
 	if(notification->background)
 		new_notification->background = g_strdup(notification->background);
 
+	if(notification->alias)
+		new_notification->alias = g_strdup(notification->alias);
+
+	new_notification->use_gtk = notification->use_gtk;
+	new_notification->width = notification->width;
+	new_notification->height = notification->height;
+
 	for(l = notification->items; l; l = l->next) {
 		GfItem *item;
 
@@ -170,6 +186,8 @@ gf_notification_to_xmlnode(GfNotification *notification) {
 	if(notification->background)
 		xmlnode_set_attrib(parent, "background", notification->background);
 
+	if(notification->alias)
+		xmlnode_set_attrib(parent, "alias", notification->alias);
 
 	data = g_strdup_printf("%d", notification->width);
 	xmlnode_set_attrib(parent, "width", data);
@@ -204,6 +222,11 @@ gf_notification_destroy(GfNotification *notification) {
 		notification->background = NULL;
 	}
 
+	if(notification->alias) {
+		g_free(notification->alias);
+		notification->alias = NULL;
+	}
+
 	if(notification->items) {
 		for(l = notification->items; l; l = l->next) {
 			item = GF_ITEM(l->data);
@@ -319,6 +342,23 @@ gf_notification_get_items(GfNotification *notification) {
 	return notification->items;
 }
 
+const gchar *
+gf_notification_get_alias(const GfNotification *notification) {
+	g_return_val_if_fail(notification, NULL);
+
+	return notification->alias;
+}
+
+void
+gf_notification_set_alias(GfNotification *notification, const gchar *alias) {
+	g_return_if_fail(notification);
+
+	if(notification->alias)
+		g_free(notification->alias);
+
+	notification->alias = (alias) ? g_strdup(alias) : NULL;
+}
+
 /*******************************************************************************
  * Finding, rendering, all that fun stuff...
  ******************************************************************************/
