@@ -39,9 +39,7 @@ typedef struct _GfNotification		GfNotification;
 #include "conversation.h"
 #include "xmlnode.h"
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
+G_BEGIN_DECLS
 
 GfNotification *gf_notification_new(GfTheme *theme);
 GfNotification *gf_notification_new_from_xmlnode(GfTheme *theme, xmlnode *node);
@@ -59,6 +57,8 @@ void gf_notification_set_width(GfNotification *notification, gint width);
 gint gf_notification_get_width(GfNotification *notification);
 void gf_notification_set_height(GfNotification *notification, gint height);
 gint gf_notification_get_height(GfNotification *notification);
+void gf_notification_set_alias(GfNotification *notification, const gchar *alias);
+const gchar *gf_notification_get_alias(const GfNotification *notification);
 
 void gf_notification_add_item(GfNotification *notification, GfItem *item);
 void gf_notification_remove_item(GfNotification *notification, GfItem *item);
@@ -75,8 +75,6 @@ GfTheme *gf_notification_get_theme(GfNotification *notification);
 void gf_notifications_init();
 void gf_notifications_uninit();
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 #endif /* GF_NOTIFICATION_H */
