@@ -34,6 +34,7 @@
 #include <gtkprefs.h>
 
 #include "gf_action.h"
+#include "gf_compat.h"
 #include "gf_display.h"
 #include "gf_event.h"
 #include "gf_file.h"
@@ -154,7 +155,7 @@ make_option_menu(const gchar *text, gchar *pref, GtkSizeGroup *sg,
 	option_menu = gtk_option_menu_new();
 	gtk_box_pack_start(GTK_BOX(hbox), option_menu, FALSE, FALSE, 0);
 
-	menu = gf_menu_build(builder);
+	menu = gf_menu_build(builder, NULL);
 	gtk_option_menu_set_menu(GTK_OPTION_MENU(option_menu), menu);
 	gtk_option_menu_set_history(GTK_OPTION_MENU(option_menu),
 								gaim_prefs_get_int(pref));
@@ -182,7 +183,7 @@ make_mouse_option_menu(const gchar *text, gchar *pref, GtkSizeGroup *sg) {
 	option_menu = gtk_option_menu_new();
 	gtk_box_pack_start(GTK_BOX(hbox), option_menu, FALSE, FALSE, 0);
 
-	menu = gf_menu_build(gf_menu_mouse);
+	menu = gf_menu_build(gf_menu_mouse, NULL);
 	gtk_option_menu_set_menu(GTK_OPTION_MENU(option_menu), menu);
 
 	action = gf_action_find_with_name(gaim_prefs_get_string(pref));
@@ -220,7 +221,7 @@ make_general_page(GtkWidget *notebook) {
 							  gf_menu_position);
 	gtk_box_pack_start(GTK_BOX(frame), option, FALSE, FALSE, 0);
 
-	label = gaim_gtk_prefs_dropdown(frame, _("Stack:"), GAIM_PREF_BOOLEAN,
+	label = gaim_gtk_prefs_dropdown(frame, _("_Stack:"), GAIM_PREF_BOOLEAN,
 									GF_PREF_APPEARANCE_VERTICAL,
 									_("Vertically"), TRUE,
 									_("Horizontally"), FALSE,
@@ -228,7 +229,7 @@ make_general_page(GtkWidget *notebook) {
 	gtk_misc_set_alignment(GTK_MISC(label), 0, 0);
 	gtk_size_group_add_widget(sg, label);
 
-	label = gaim_gtk_prefs_dropdown(frame, _("Show while away:"),
+	label = gaim_gtk_prefs_dropdown(frame, _("Show _while away:"),
 									GAIM_PREF_BOOLEAN,
 									GF_PREF_BEHAVIOR_SHOW_WHILE_AWAY,
 									_("Yes"), TRUE,
@@ -237,7 +238,7 @@ make_general_page(GtkWidget *notebook) {
 	gtk_misc_set_alignment(GTK_MISC(label), 0, 0);
 	gtk_size_group_add_widget(sg, label);
 
-	label = gaim_gtk_prefs_dropdown(frame, _("Animate:"), GAIM_PREF_BOOLEAN,
+	label = gaim_gtk_prefs_dropdown(frame, _("_Animate:"), GAIM_PREF_BOOLEAN,
 									GF_PREF_APPEARANCE_ANIMATE,
 									_("Yes"), TRUE,
 									_("No"), FALSE,
@@ -255,13 +256,13 @@ make_general_page(GtkWidget *notebook) {
 	frame = gaim_gtk_make_frame(vbox, _("Mouse"));
 	gtk_widget_show(frame);
 
-	option = make_mouse_option_menu(_("Left:"), GF_PREF_MOUSE_LEFT, sg);
+	option = make_mouse_option_menu(_("_Left:"), GF_PREF_MOUSE_LEFT, sg);
 	gtk_box_pack_start(GTK_BOX(frame), option, FALSE, FALSE, 0);
 
-	option = make_mouse_option_menu(_("Middle:"), GF_PREF_MOUSE_MIDDLE, sg);
+	option = make_mouse_option_menu(_("_Middle:"), GF_PREF_MOUSE_MIDDLE, sg);
 	gtk_box_pack_start(GTK_BOX(frame), option, FALSE, FALSE, 0);
 
-	option = make_mouse_option_menu(_("Right:"), GF_PREF_MOUSE_RIGHT, sg);
+	option = make_mouse_option_menu(_("_Right:"), GF_PREF_MOUSE_RIGHT, sg);
 	gtk_box_pack_start(GTK_BOX(frame), option, FALSE, FALSE, 0);
 }
 
@@ -613,7 +614,8 @@ theme_got_url(void *data, const char *themedata, size_t len)
 	FILE *f;
 	gchar *path;
 
-	f = gaim_mkstemp(&path);
+	f = gf_mkstemp(&path);
+	
 	fwrite(themedata, len, 1, f);
 	fclose(f);
 
@@ -626,7 +628,7 @@ theme_got_url(void *data, const char *themedata, size_t len)
 static void
 theme_dnd_recv(GtkWidget *widget, GdkDragContext *dc, guint x, guint y, GtkSelectionData *sd,
 				guint info, guint t, gpointer data) {
-	gchar *name = sd->data;
+	gchar *name = (gchar *)sd->data;
 
 	if ((sd->length >= 0) && (sd->format == 8)) {
 		/* Well, it looks like the drag event was cool.
@@ -1267,13 +1269,13 @@ make_advanced_page(GtkWidget *notebook) {
 
 	frame = gaim_gtk_make_frame(vbox, _("Release Notification"));
 
-	gaim_gtk_prefs_checkbox(_("Check for new releases"),
+	gaim_gtk_prefs_checkbox(_("_Check for new releases"),
 							GF_PREF_ADVANCED_RELEASE_NOTIFICATION, 	 
 							frame);
 
 	frame = gaim_gtk_make_frame(vbox, _("Display Options"));
 
-	gaim_gtk_prefs_labeled_spin_button(frame, _("_Max Visible Guifications:"),
+	gaim_gtk_prefs_labeled_spin_button(frame, _("Max _Visible Guifications:"),
 									   GF_PREF_BEHAVIOR_THROTTLE,
 									   0, 255, sg);
 #if GTK_CHECK_VERSION(2,2,0)
@@ -1284,14 +1286,14 @@ make_advanced_page(GtkWidget *notebook) {
 
 		if(screen_count > 0) {
 			gaim_gtk_prefs_labeled_spin_button(frame,
-											_("Show notifications on screen:"),
+											_("Show notifications on _screen:"),
 											GF_PREF_ADVANCED_SCREEN,
 											0, screen_count, sg);
 		}
 
 		if(monitor_count > 0) {
 			gaim_gtk_prefs_labeled_spin_button(frame,
-											_("Show notifications on monitor:"),
+											_("Show notifications on _monitor:"),
 											GF_PREF_ADVANCED_MONITOR,
 											0, monitor_count, sg);
 		}
@@ -1347,6 +1349,7 @@ gf_preferences_add() {
 	gaim_prefs_add_none(GF_PREF_BEHAVIOR_ROOT);
 	gaim_prefs_add_int(GF_PREF_BEHAVIOR_DISPLAY_TIME, 6);
 	gaim_prefs_add_int(GF_PREF_BEHAVIOR_THROTTLE, 6);
+	gaim_prefs_add_bool(GF_PREF_BEHAVIOR_SHOW_WHILE_AWAY, TRUE);
 
 	gaim_prefs_add_none(GF_PREF_APPEARANCE_ROOT);
 	gaim_prefs_add_int(GF_PREF_APPEARANCE_POSITION, GF_DISPLAY_POSITION_SE);
@@ -1390,7 +1393,6 @@ gf_preferences_add() {
 
 	/* clean up old prefs if they exist */
 	gaim_prefs_remove("/plugins/gtk/amc_grim/guifications2/behavior/show_during_screen_saver");
-	gaim_prefs_remove("/plugins/gtk/amc_grim/guifications2/behavior/show_while_away");
 	gaim_prefs_remove("/plugins/gtk/amc_grim/guifications2/appearance/h_offset");
 	gaim_prefs_remove("/plugins/gtk/amc_grim/guifications2/appearance/h_offset");
 	gaim_prefs_remove("/plugins/gtk/amc_grim/guifications2/appearance/zoom");
