@@ -19,14 +19,10 @@
 #ifndef GF_RELEASE_H
 #define GF_RELEASE_H
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
+G_BEGIN_DECLS
 
 void gf_release_check();
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 #endif /* GF_RELEASE_H */
