@@ -27,8 +27,8 @@ static GtkIconFactory *icon_factory;
 
 static gchar *
 gf_stock_file_name(const gchar *file_name) {
-	return g_build_filename(DATADIR, "pixmaps", "gaim", "guifications", "conf",
-							file_name, NULL);
+	return g_build_filename(DATADIR, "pixmaps", "gaim", "guifications",
+							"conf", file_name, NULL);
 }
 
 static void
@@ -42,7 +42,7 @@ gf_add_to_stock(const gchar *file_name, const gchar *stock_name) {
 	g_free(file);
 
 	if(!pixbuf) {
-		gaim_debug_info("guifications", "failed to load stock item '%s'\n",
+		gaim_debug_info("Guifications", "failed to load stock item '%s'\n",
 						stock_name);
 		return;
 	}
@@ -63,9 +63,6 @@ gf_stock_init() {
 	gf_add_to_stock("window_position_north_west.png", GF_STOCK_WINDOW_POSITION_NORTH_WEST);
 	gf_add_to_stock("window_position_south_east.png", GF_STOCK_WINDOW_POSITION_SOUTH_EAST);
 	gf_add_to_stock("window_position_south_west.png", GF_STOCK_WINDOW_POSITION_SOUTH_WEST);
-	gf_add_to_stock("window_zoom_in.png", GF_STOCK_WINDOW_ZOOM_IN);
-	gf_add_to_stock("window_zoom_normal.png", GF_STOCK_WINDOW_ZOOM_NORMAL);
-	gf_add_to_stock("window_zoom_out.png", GF_STOCK_WINDOW_ZOOM_OUT);
 	gf_add_to_stock("item_icon_size_big.png", GF_STOCK_ITEM_ICON_SIZE_BIG);
 	gf_add_to_stock("item_icon_size_huge.png", GF_STOCK_ITEM_ICON_SIZE_HUGE);
 	gf_add_to_stock("item_icon_size_large.png", GF_STOCK_ITEM_ICON_SIZE_LARGE);
