@@ -23,9 +23,6 @@
 #define GF_STOCK_WINDOW_POSITION_NORTH_EAST "gf_window_north_east"
 #define GF_STOCK_WINDOW_POSITION_SOUTH_WEST "gf_window_south_west"
 #define GF_STOCK_WINDOW_POSITION_SOUTH_EAST "gf_window_south_east"
-#define GF_STOCK_WINDOW_ZOOM_IN "gf_window_zoom_in"
-#define GF_STOCK_WINDOW_ZOOM_NORMAL "gf_window_zoom_normal"
-#define GF_STOCK_WINDOW_ZOOM_OUT "gf_window_zoom_out"
 #define GF_STOCK_ITEM_ICON_SIZE_BIG "item_icon_size_big"
 #define GF_STOCK_ITEM_ICON_SIZE_HUGE "item_icon_size_huge"
 #define GF_STOCK_ITEM_ICON_SIZE_LARGE "item_icon_size_large"
@@ -47,7 +44,11 @@
 #define GF_STOCK_ITEM_TEXT_CLIPPING_ELLIPSIS_START "item_text_clipping_ellipsis_start"
 #define GF_STOCK_ITEM_TEXT_CLIPPING_TRUNCATE "item_text_clipping_truncate"
 
+G_BEGIN_DECLS
+
 void gf_stock_init();
 void gf_stock_uninit();
 
+G_END_DECLS
+
 #endif /* GF_STOCK_H */
