@@ -44,6 +44,8 @@ struct _GfTheme {
 	GfThemeOptions *ops;
 
 	GList *notifications;
+
+	GfNotification *master;
 };
 
 #include "gf_theme.h"
@@ -160,7 +162,7 @@ gf_theme_find_theme_by_name(const gchar *name) {
 	for(l = loaded_themes; l; l = l->next) {
 		theme = GF_THEME(l->data);
 
-		if(!g_ascii_strcasecmp(gf_theme_info_get_name(theme->info), name))
+		if(!g_utf8_collate(gf_theme_info_get_name(theme->info), name))
 			return theme;
 	}
 
@@ -344,8 +346,8 @@ gf_themes_probe() {
 	const gchar *file;
 	gint i;
 
-	probe_dirs[0] = g_build_filename(DATADIR, "pixmaps", "gaim", "guifications",
-									 "themes", NULL);
+	probe_dirs[0] = g_build_filename(DATADIR, "pixmaps", "gaim",
+									 "guifications", "themes", NULL);
 	probe_dirs[1] = g_build_filename(gaim_user_dir(), "guifications", "themes",
 									 NULL);
 	probe_dirs[2] = NULL;
@@ -440,6 +442,21 @@ gf_theme_get_path(GfTheme *theme) {
 	return theme->path;
 }
 
+GfNotification *
+gf_theme_get_master(GfTheme *theme) {
+	g_return_val_if_fail(theme, NULL);
+
+	return theme->master;
+}
+
+void
+gf_theme_set_master(GfTheme *theme, GfNotification *notification) {
+	g_return_if_fail(theme);
+	g_return_if_fail(notification);
+
+	theme->master = notification;
+}
+
 static void
 gf_theme_get_supported_func(gpointer key, gpointer val, gpointer data) {
 	GString *str = data;
@@ -534,17 +551,43 @@ gf_theme_get_theme_options(GfTheme *theme) {
 
 void
 gf_theme_add_notification(GfTheme *theme, GfNotification *notification) {
+	const gchar *type = NULL;
+
 	g_return_if_fail(theme);
 	g_return_if_fail(notification);
 
+	type = gf_notification_get_type(notification);
+	if(!g_utf8_collate(GF_NOTIFICATION_MASTER, type)) {
+		if(theme->master) {
+			const gchar *name = NULL;
+
+			name = gf_theme_info_get_name(theme->info);
+			gaim_debug_info("Guifications",
+							"Theme %s already has a master notification\n",
+							name ? name : "(NULL)");
+			return;
+		} else {
+			theme->master = notification;
+		}
+	}
+
 	theme->notifications = g_list_append(theme->notifications, notification);
 }
 
 void
 gf_theme_remove_notification(GfTheme *theme, GfNotification *notification) {
+	const gchar *type = NULL;
+
 	g_return_if_fail(theme);
 	g_return_if_fail(notification);
 
+	type = gf_notification_get_type(notification);
+	if(!g_utf8_collate(GF_NOTIFICATION_MASTER, type)) {
+		gaim_debug_info("Guifications",
+						"Master notifications can not be removed\n");
+		return;
+	}
+
 	theme->notifications = g_list_remove(theme->notifications, notification);
 }
 
