@@ -37,9 +37,7 @@ typedef struct _GfTheme			GfTheme;
 #include "gf_theme_info.h"
 #include "gf_theme_ops.h"
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
+G_BEGIN_DECLS
 
 GfTheme *gf_theme_new();
 GfTheme *gf_theme_new_from_file(const gchar *filename);
@@ -62,6 +60,8 @@ void gf_themes_unprobe();
 gint gf_theme_get_api_version(GfTheme *theme);
 const gchar *gf_theme_get_filename(GfTheme *theme);
 const gchar *gf_theme_get_path(GfTheme *theme);
+GfNotification *gf_theme_get_master(GfTheme *theme);
+void gf_theme_set_master(GfTheme *theme, GfNotification *notification);
 gchar *gf_theme_get_supported_notifications(GfTheme *theme);
 void gf_theme_set_theme_info(GfTheme *theme, GfThemeInfo *info);
 GfThemeInfo *gf_theme_get_theme_info(GfTheme *theme);
@@ -78,8 +78,6 @@ void gf_themes_unload();
 void gf_themes_save_loaded();
 void gf_themes_load_saved();
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 #endif /* GF_THEME_H */
