@@ -52,6 +52,7 @@
 #include "gf_theme_editor.h"
 #include "gf_theme_info.h"
 #include "gf_theme_ops.h"
+#include "gf_utils.h"
 
 /* Okay, heres the run down of how all of this works.
  *
@@ -122,6 +123,7 @@ struct GfThemeEditorOps {
 };
 
 struct GfThemeEditorNotification {
+	GtkWidget *alias;
 	GtkWidget *use_gtk;
 	GtkWidget *filename;
 	GtkWidget *button;
@@ -160,7 +162,6 @@ struct GfThemeEditorText {
 
 struct GfThemeEditor {
 	GfTheme *theme;
-	GfNotification *master;
 
 	gchar *filename;
 	gchar *path;
@@ -352,10 +353,21 @@ gfte_store_update() {
 
 	/* notifications */
 	for(n = gf_theme_get_notifications(editor.theme); n; n = n->next) {
+		const gchar *alias = NULL, *name = NULL;
+
 		notification = GF_NOTIFICATION(n->data);
-		event = gf_event_find_for_notification(gf_notification_get_type(notification));
-		gfte_store_add(store, &child, &parent,
-					   gf_event_get_name(event),
+
+		if((alias = gf_notification_get_alias(notification)))
+			name = alias;
+		else {
+			const gchar *type;
+
+			type = gf_notification_get_type(notification);
+			event = gf_event_find_for_notification(type);
+			name = gf_event_get_name(event);
+		}
+
+		gfte_store_add(store, &child, &parent, name,
 					   GFTE_PAGE_NOTIFICATION, notification);
 
 		/* items */
@@ -461,21 +473,17 @@ gfte_setup(const gchar *filename) {
 
 		for(l = gf_theme_get_notifications(editor.theme); l; l = l->next) {
 			notification = GF_NOTIFICATION(l->data);
-
-			if(!g_ascii_strcasecmp(GF_NOTIFICATION_MASTER,
-								   gf_notification_get_type(notification))) {
-				editor.master = notification;
-				break;
-			}
 		}
 	} else {
+		GfNotification *master = NULL;
+
 		editor.theme = gf_theme_new();
 		gf_theme_set_theme_info(editor.theme, gf_theme_info_new());
 		gf_theme_set_theme_options(editor.theme, gf_theme_options_new());
 
-		editor.master = gf_notification_new(editor.theme);
-		gf_notification_set_type(editor.master, GF_NOTIFICATION_MASTER);
-		gf_theme_add_notification(editor.theme, editor.master);
+		master = gf_notification_new(editor.theme);
+		gf_notification_set_type(master, GF_NOTIFICATION_MASTER);
+		gf_theme_add_notification(editor.theme, master);
 	}
 
 	if(editor.theme) {
@@ -918,7 +926,7 @@ gfte_new_notification_cancel_cb(GtkButton *button, gpointer data) {
 
 static void
 gfte_new_notification_ok_cb(GtkButton *button, gpointer data) {
-	GfNotification *notification;
+	GfNotification *notification, *master;
 	GtkTreeIter parent, child;
 	gpointer object;
 	const gchar *n_type;
@@ -938,17 +946,22 @@ gfte_new_notification_ok_cb(GtkButton *button, gpointer data) {
 		return;
 	}
 
-	if(!editor.master) {
-		notification = gf_notification_new(GF_THEME(object));
-	} else {
-		notification = gf_notification_copy(editor.master);
-	}
-
 	/* find the notification type, this really needs to get cleaned up but works for now
 	 */
 	hist = gtk_option_menu_get_history(GTK_OPTION_MENU(new_notification.type));
 	n_type = gf_events_get_nth_notification(hist);
 
+	if(!g_utf8_collate(n_type, GF_NOTIFICATION_MASTER))
+		return;
+
+	master = gf_theme_get_master(editor.theme);
+
+	if(!master) {
+		notification = gf_notification_new(GF_THEME(object));
+	} else {
+		notification = gf_notification_copy(master);
+	}
+
 	/* create the notification */
 	gf_notification_set_type(notification, n_type);
 
@@ -962,7 +975,7 @@ gfte_new_notification_ok_cb(GtkButton *button, gpointer data) {
 				   notification);
 	gfte_store_select_iter(&child);
 
-	if(editor.master) {
+	if(master) {
 		GtkTreeIter item;
 		GList *l;
 		gboolean expand = FALSE;
@@ -1023,7 +1036,7 @@ gfte_new_notification_show(GtkButton *button, gpointer data) {
 	widget = gtk_label_new(_("New notification type:"));
 	gtk_box_pack_start(GTK_BOX(hbox), widget, FALSE, FALSE, 0);
 
-	menu = gf_menu_build(gf_menu_event);
+	menu = gf_menu_build(gf_menu_event, editor.theme);
 	new_notification.type = gtk_option_menu_new();
 	gtk_option_menu_set_menu(GTK_OPTION_MENU(new_notification.type), menu);
 	gtk_box_pack_start(GTK_BOX(hbox), new_notification.type, TRUE, TRUE, 0);
@@ -1179,7 +1192,7 @@ gfte_new_item_show(GtkButton *button, gpointer data) {
 	widget = gtk_label_new(_("New item type:"));
 	gtk_box_pack_start(GTK_BOX(hbox), widget, FALSE, FALSE, 0);
 
-	menu = gf_menu_build(gf_menu_item_type);
+	menu = gf_menu_build(gf_menu_item_type, NULL);
 	new_item.type = gtk_option_menu_new();
 	gtk_option_menu_set_menu(GTK_OPTION_MENU(new_item.type), menu);
 	gtk_box_pack_start(GTK_BOX(hbox), new_item.type, TRUE, TRUE, 0);
@@ -1481,22 +1494,30 @@ gfte_move_down(GtkButton *button, gpointer data) {
  * getter/setter helpers
  ******************************************************************************/
 static gpointer
-gfte_store_get_object() {
-	GtkTreeIter iter;
+gfte_store_get_object_and_iter(GtkTreeIter *iter) {
 	GtkTreeModel *model;
 	GtkTreeSelection *sel;
 	gpointer object;
 
-    sel = gtk_tree_view_get_selection(GTK_TREE_VIEW(editor.tree));
-	gtk_tree_selection_get_selected(sel, &model, &iter);
+	g_return_val_if_fail(iter, NULL);
 
-	gtk_tree_model_get(model, &iter,
+    sel = gtk_tree_view_get_selection(GTK_TREE_VIEW(editor.tree));
+	gtk_tree_selection_get_selected(sel, &model, iter);
+
+	gtk_tree_model_get(model, iter,
 					   GFTE_STORE_OBJECT, &object,
 					   -1);
 
 	return object;
 }
 
+static gpointer
+gfte_store_get_object() {
+	GtkTreeIter iter;
+
+	return gfte_store_get_object_and_iter(&iter);
+}
+
 /*******************************************************************************
  * Setters
  ******************************************************************************/
@@ -1585,13 +1606,39 @@ gfte_set_value(GtkWidget *widget, gint page, gpointer object, gconstpointer valu
 
 static void
 gfte_entry_changed_cb(GtkWidget *widget, gpointer data) {
-	gpointer object = gfte_store_get_object();
-	gpointer value = (gpointer)gtk_entry_get_text(GTK_ENTRY(widget));
-	gint page = gtk_notebook_get_current_page(GTK_NOTEBOOK(editor.note));
+	GtkTreeIter iter;
+	gpointer object;
+	const gchar *value;
+	gint page;
+
+	object = gfte_store_get_object_and_iter(&iter);
+	value  = gtk_entry_get_text(GTK_ENTRY(widget));
+	page = gtk_notebook_get_current_page(GTK_NOTEBOOK(editor.note));
 
 	editor.changed = TRUE;
 
-	gfte_set_value(widget, page, object, value);
+	gfte_set_value(widget, page, object, (gpointer)value);
+
+	if(page == GFTE_PAGE_NOTIFICATION && widget == editor.notification.alias) {
+		GfEvent *event;
+		GfNotification *notification;
+		const gchar *alias = NULL, *type = NULL;
+
+		if(!gf_utils_strcmp(value, "")) {
+			notification = GF_NOTIFICATION(object);
+
+			type = gf_notification_get_type(notification);
+			event = gf_event_find_for_notification(type);
+
+			alias = gf_event_get_name(event);
+		} else {
+			alias = value;
+		}
+
+		gtk_tree_store_set(editor.store, &iter,
+						   GFTE_STORE_TITLE, alias,
+						   -1);
+	}
 }
 
 static void
@@ -2001,8 +2048,14 @@ gfte_update_ops_page() {
 
 static void
 gfte_update_notification_page() {
-	GfNotification *notification = GF_NOTIFICATION(gfte_store_get_object());
+	gpointer obj;
+	GfNotification *notification;
 
+	obj = gfte_store_get_object();
+	notification = GF_NOTIFICATION(obj);
+
+	gfte_update_entry(editor.notification.alias, GFTE_PAGE_NOTIFICATION,
+					  notification);
 	gfte_update_check(editor.notification.use_gtk, GFTE_PAGE_NOTIFICATION,
 					  notification);
 	gfte_update_entry(editor.notification.filename, GFTE_PAGE_NOTIFICATION,
@@ -2131,7 +2184,7 @@ gfte_save_theme_cb(GtkButton *button, gpointer data) {
 
 static void
 gfte_help(GtkButton *button, gpointer data) {
-	gaim_notify_uri(NULL, GF_WEBSITE "/themes/howto.php");
+	gaim_notify_uri(NULL, GF_WEBSITE "/themes/theme_howto/");
 }
 
 /*******************************************************************************
@@ -2261,7 +2314,7 @@ gfte_add_option_menu(GtkWidget *parent, GtkSizeGroup *sg, gint flags,
 
 	option_menu = gtk_option_menu_new();
 	gtk_option_menu_set_menu(GTK_OPTION_MENU(option_menu),
-							 gf_menu_build(builder));
+							 gf_menu_build(builder, NULL));
 	g_object_set_data(G_OBJECT(option_menu), "getter", getter);
 	g_object_set_data(G_OBJECT(option_menu), "setter", setter);
 	g_object_set_data(G_OBJECT(option_menu), "flags", GINT_TO_POINTER(flags));
@@ -2385,6 +2438,11 @@ gfte_make_notification_page() {
 	page = gtk_vbox_new(FALSE, 4);
 	gtk_container_set_border_width(GTK_CONTAINER(page), 12);
 
+	editor.notification.alias =
+					gfte_add_entry(page, sg, GFTE_FLAGS_OBJECT, _("Alias:"),
+								   gf_notification_get_alias,
+								   gf_notification_set_alias);
+
 	editor.notification.use_gtk =
 					gfte_add_check(page, GFTE_FLAGS_OBJECT,
 								   _("Use Gtk theme background"),
