@@ -23,16 +23,12 @@
 
 #include <plugin.h>
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
+G_BEGIN_DECLS
 
 void gf_theme_editor_init(GaimPlugin *plugin);
 void gf_theme_editor_uninit();
 void gf_theme_editor_show(const gchar *filename);
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 #endif /* GF_THEME_EDITOR_H */
