@@ -159,7 +159,7 @@ gf_theme_info_destroy(GfThemeInfo *info) {
 gchar *
 gf_theme_info_strip_name(GfThemeInfo *info) {
 	GString *str;
-	const gchar *name, *iter;
+	const gchar *iter;
 	gchar *dir;
 
 	g_return_val_if_fail(info, NULL);
@@ -169,10 +169,12 @@ gf_theme_info_strip_name(GfThemeInfo *info) {
 
 	str = g_string_new("");
 
-	if(info->name[0] == '.' && strlen(info->name) > 1)
-		name++;
+	iter = info->name;
 
-	for(iter = info->name; *iter != '\0'; iter++)
+	if(iter[0] == '.' && strlen(iter) > 1)
+		iter++;
+
+	for(; *iter != '\0'; iter++)
 	{
 		switch(iter[0]) {
 			case '\\':
