@@ -27,9 +27,7 @@ typedef struct _GfThemeInfo GfThemeInfo;
 
 #include "xmlnode.h"
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
+G_BEGIN_DECLS
 
 GfThemeInfo *gf_theme_info_new();
 GfThemeInfo *gf_theme_info_new_from_xmlnode(xmlnode *node);
@@ -51,8 +49,6 @@ const gchar *gf_theme_info_get_author(GfThemeInfo *info);
 void gf_theme_info_set_website(GfThemeInfo *info, const gchar *author);
 const gchar *gf_theme_info_get_website(GfThemeInfo *info);
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 #endif
