@@ -27,9 +27,7 @@ typedef struct _GfThemeOptions GfThemeOptions;
 
 #include "xmlnode.h"
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
+G_BEGIN_DECLS
 
 GfThemeOptions *gf_theme_options_new();
 GfThemeOptions *gf_theme_options_new_from_xmlnode(xmlnode *node);
@@ -45,8 +43,6 @@ const gchar *gf_theme_options_get_warning(GfThemeOptions *ops);
 void gf_theme_options_set_ellipsis(GfThemeOptions *ops, const gchar *ellipsis);
 const gchar *gf_theme_options_get_ellipsis(GfThemeOptions *ops);
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 #endif /* GF_THEME_OPTIONS_H */
