@@ -21,15 +21,11 @@
 
 #include <glib.h>
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
+G_BEGIN_DECLS
 
 gint gf_utils_strcmp(const gchar *s1, const gchar *s2);
 gint gf_utils_compare_strings(gconstpointer a, gconstpointer b);
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 #endif /* GF_UTILS_H */
