@@ -48,7 +48,7 @@ gf_load(GaimPlugin *plugin) {
 	gf_events_init(plugin);
 	gf_theme_editor_init(plugin);
 	gf_item_text_init();
-	gf_display_init();
+	gf_display_init(plugin);
 	gf_gtk_utils_init();
 	gf_stock_init();
 	gf_themes_probe();
@@ -111,12 +111,12 @@ static GaimPluginInfo gf_info = {
 
 static void
 init_plugin(GaimPlugin *plugin) {
-
+	
 #ifdef ENABLE_NLS
 	bindtextdomain(GF_PACKAGE, LOCALEDIR);
 	bind_textdomain_codeset(GF_PACKAGE, "UTF-8");
-#endif
-
+#endif /* ENABLE_NLS */
+	
 	gf_info.name		= _("Guifications");
 	gf_info.summary		= _("The end all, be all, toaster popup plugin");
 	gf_info.description	= _("Guifications:\n"
